s1etad module API
=================

.. automodule:: s1etad


.. _Sentinel1Etad-class-label:

Sentinel1Etad class
-------------------

.. autoclass:: s1etad.Sentinel1Etad
   :members:
   :undoc-members:
   :show-inheritance:


.. _Sentinel1EtadSwath-class-label:

Sentinel1EtadSwath class
------------------------

.. autoclass:: s1etad.Sentinel1EtadSwath
   :members:
   :undoc-members:
   :show-inheritance:


.. _Sentinel1EtadBurst-class-label:

Sentinel1EtadBurst class
------------------------

.. autoclass:: s1etad.Sentinel1EtadBurst
   :members:
   :undoc-members:
   :show-inheritance:


ECorrectionType enum
--------------------

.. autoclass:: s1etad.ECorrectionType
   :members:
   :undoc-members:
   :show-inheritance:
